@@ -33,13 +33,8 @@ describe 'barbican::db' do
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
       )}
-
-      # TODO(aschultz): remove once oslo is properly used
-      it { should contain_barbican_config('DEFAULT/sql_connection').with_value('sqlite:////var/lib/barbican/barbican.sqlite') }
-      it { should contain_barbican_config('DEFAULT/sql_idle_timeout').with_value('<SERVICE DEFAULT>') }
-      it { should contain_barbican_config('DEFAULT/sql_pool_size').with_value('<SERVICE DEFAULT>') }
-      it { should contain_barbican_config('DEFAULT/sql_pool_max_overflow').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with specific parameters' do
@@ -52,6 +47,7 @@ describe 'barbican::db' do
           :database_retry_interval          => '11',
           :database_max_overflow            => '11',
           :database_pool_timeout            => '11',
+          :mysql_enable_ndb                 => true,
           :database_pool_size               => '2',
           :database_db_max_retries          => '-1',
         }
@@ -68,13 +64,8 @@ describe 'barbican::db' do
         :retry_interval          => '11',
         :max_overflow            => '11',
         :pool_timeout            => '11',
+        :mysql_enable_ndb        => true,
       )}
-
-      # TODO(aschultz) remove once oslo is properly used
-      it { should contain_barbican_config('DEFAULT/sql_connection').with_value('mysql+pymysql://barbican:barbican@localhost/barbican').with_secret(true) }
-      it { should contain_barbican_config('DEFAULT/sql_idle_timeout').with_value('3601') }
-      it { should contain_barbican_config('DEFAULT/sql_pool_size').with_value('2') }
-      it { should contain_barbican_config('DEFAULT/sql_pool_max_overflow').with_value('11') }
     end
   end
 
